@@ -9,9 +9,9 @@ from argparse import (
 )
 
 import numpy as np
-import pyDOE as doe
 from scipy.stats.distributions import norm
 
+import pyDOE2 as doe
 from spellbook.utils import prep_argparse
 
 
@@ -113,6 +113,9 @@ def process_args(args):
     elif sample_type == "star":
         _x = doe.doe_star.star(n_dims)[0]
         x = 0.5 * (_x + 1.0)  # transform to center at 0.5 (range 0-1)
+    elif sample_type == "ccf" or sample_type == "ccc" or sample_type == "cci":
+        _x = np.unique(doe.ccdesign(n_dims, face=sample_type), axis=0)
+        x = 0.5 * (_x + 1.0)
     else:
         raise ValueError(sample_type + " is not a valid choice for sample_type!")
 
@@ -136,7 +139,7 @@ def process_args(args):
 
     # add x0
     if args.x0 is not None:
-        x0 = np.load(args.x0)
+        x0 = np.atleast_2d(np.load(args.x0))
         if scales is not None:
             sa = args.scale_factor * np.array(scales)[:, :2].astype("float")
             center = np.mean(sa, axis=1)
@@ -195,7 +198,7 @@ def setup_argparse(parent_parser=None, the_subparser=None):
     make_samples.add_argument("-dims", help="number of dimensions", default=2, type=int)
     make_samples.add_argument(
         "-sample_type",
-        help="type of sampling. options: random, grid, lhs, lhd, star. If grid, will try to get close to the correct number of samples. for lhd min-max correspond to +- 3 sigma range",
+        help="type of sampling. options: random, grid, lhs, lhd, star, ccf, ccc, cci. If grid, will try to get close to the correct number of samples. for lhd min-max correspond to +- 3 sigma range",
         default="random",
     )
     make_samples.add_argument(
